@@ -136,13 +136,21 @@ lsm_c_para_sd_calc <- function(landscape, directions, resolution = NULL){
                             directions = directions,
                             resolution = resolution)
 
-    para_sd <- stats::aggregate(x = para[, 5], by = para[, 2], FUN = stats::sd)
+    # all cells are NA
+    if (all(is.na(para$value))) {
+        return(tibble::tibble(level = "class",
+                              class = as.integer(NA),
+                              id = as.integer(NA),
+                              metric = "para_sd",
+                              value = as.double(NA)))
+    }
 
-    tibble::tibble(
-        level = "class",
-        class = as.integer(para_sd$class),
-        id = as.integer(NA),
-        metric = "para_sd",
-        value = as.double(para_sd$value)
-    )
+    para_sd <- stats::aggregate(x = para[, 5], by = para[, 2],
+                                FUN = stats::sd)
+
+    return(tibble::tibble(level = "class",
+                          class = as.integer(para_sd$class),
+                          id = as.integer(NA),
+                          metric = "para_sd",
+                          value = as.double(para_sd$value)))
 }
