@@ -149,13 +149,21 @@ lsm_c_tca_calc <- function(landscape, directions, consider_boundary, edge_depth,
                                  edge_depth = edge_depth,
                                  resolution = resolution)
 
-    core_area <- stats::aggregate(x = core_area[, 5], by = core_area[, 2], FUN = sum)
+    # all cells are NA
+    if (all(is.na(core_area$value))) {
+        return(tibble::tibble(level = "class",
+                              class = as.integer(NA),
+                              id = as.integer(NA),
+                              metric = "tca",
+                              value = as.double(NA)))
+    }
 
-    tibble::tibble(
-        level = "class",
-        class = as.integer(core_area$class),
-        id = as.integer(NA),
-        metric = "tca",
-        value = as.double(core_area$value)
-    )
+    core_area <- stats::aggregate(x = core_area[, 5], by = core_area[, 2],
+                                  FUN = sum)
+
+    return(tibble::tibble(level = "class",
+                          class = as.integer(core_area$class),
+                          id = as.integer(NA),
+                          metric = "tca",
+                          value = as.double(core_area$value)))
 }
