@@ -134,16 +134,23 @@ lsm_l_area_sd_calc <- function(landscape, directions, resolution = NULL){
                                   directions = directions,
                                   resolution = resolution)
 
+    # all values NA
+    if (all(is.na(area_patch$value))) {
+        return(tibble::tibble(level = "landscape",
+                              class = as.integer(NA),
+                              id = as.integer(NA),
+                              metric = "area_sd",
+                              value = as.double(NA)))
+    }
+
     # calculate sd
     area_sd <- stats::sd(area_patch$value)
 
-    tibble::tibble(
-        level = "landscape",
-        class = as.integer(NA),
-        id = as.integer(NA),
-        metric = "area_sd",
-        value = as.double(area_sd)
-    )
+    return(tibble::tibble(level = "landscape",
+                          class = as.integer(NA),
+                          id = as.integer(NA),
+                          metric = "area_sd",
+                          value = as.double(area_sd)))
 }
 
 
