@@ -169,13 +169,20 @@ lsm_l_cai_cv_calc <- function(landscape, directions, consider_boundary, edge_dep
                                 edge_depth = edge_depth,
                                 resolution = resolution)
 
+    # all values NA
+    if (all(is.na(cai_patch$value))) {
+        return(tibble::tibble(level = "landscape",
+                              class = as.integer(NA),
+                              id = as.integer(NA),
+                              metric = "cai_cv",
+                              value = as.double(NA)))
+    }
+
     cai_cv <- raster::cv(cai_patch$value)
 
-    tibble::tibble(
-        level = "landscape",
-        class = as.integer(NA),
-        id = as.integer(NA),
-        metric = "cai_cv",
-        value = as.double(cai_cv)
-    )
+    return(tibble::tibble(level = "landscape",
+                          class = as.integer(NA),
+                          id = as.integer(NA),
+                          metric = "cai_cv",
+                          value = as.double(cai_cv)))
 }
