@@ -2,6 +2,17 @@ context("landscape level lsm_l_te metric")
 
 landscapemetrics_landscape_landscape_value <- lsm_l_te(landscape)
 
+test_lsm <- matrix(data = NA, nrow = 25, ncol = 30)
+
+test_lsm[c(5:7), c(5:7)] <- 1
+test_lsm[4, 6] <- 1
+test_lsm[6, 8] <- 1
+test_lsm[8, 6] <- 1
+test_lsm[6, 4] <- 1
+test_lsm[6, 6] <- 2
+
+test_lsm <- raster::raster(test_lsm, xmn = 0, xmx = 30, ymn = 0, ymx = 25)
+
 test_that("lsm_l_te is typestable", {
     expect_is(lsm_l_te(landscape), "tbl_df")
     expect_is(lsm_l_te(landscape_stack), "tbl_df")
@@ -31,3 +42,16 @@ test_that("lsm_l_te option count_boundary is working", {
 test_that("lsm_l_te can handle raster with different xy resolution", {
     expect_is(lsm_l_te(landscape_diff_res), "tbl_df")
 })
+
+
+test_that("lsm_l_te is the same if count_boundary = FALSE", {
+
+    result_cbF <- lsm_c_te(test_lsm, count_boundary = FALSE)
+    result_cbT <- lsm_c_te(test_lsm, count_boundary = TRUE)
+
+    result_l_cbF <- lsm_l_te(test_lsm, count_boundary = FALSE)
+    result_l_cbT <- lsm_l_te(test_lsm, count_boundary = TRUE)
+
+    expect_true(all(result_l_cbF$value == result_cbF$value))
+    expect_true(all(result_l_cbT$value == max(result_cbT$value)))
+})
